@@ -24,14 +24,10 @@
 #ifndef __GST_FDSINK_H__
 #define __GST_FDSINK_H__
 
-
-#include <config.h>
 #include <gst/gst.h>
 
 G_BEGIN_DECLS
 
-GstElementDetails gst_fdsink_details;
-
 
 #define GST_TYPE_FDSINK \
   (gst_fdsink_get_type())
