@@ -189,7 +189,7 @@ gst_init_get_popt_table (void)
     {"gst-plugin-load", NUL, POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
           ARG_PLUGIN_LOAD,
           N_("Comma-separated list of plugins to preload in addition to the "
-              "list stored in envronment variable GST_PLUGIN_PATH"),
+              "list stored in environment variable GST_PLUGIN_PATH"),
         N_("PLUGINS")},
     {"gst-disable-segtrap", NUL, POPT_ARG_NONE | POPT_ARGFLAG_STRIP, NULL,
           ARG_SEGTRAP_DISABLE,
@@ -312,7 +312,6 @@ gst_init_check_with_popt_table (int *argc, char **argv[],
   poptContext context;
   gint nextopt;
   GstPoptOption *options;
-  const gchar *gst_debug_env = NULL;
 
   GstPoptOption options_with[] = {
     {NULL, NUL, POPT_ARG_INCLUDE_TABLE, poptHelpOptions, 0, "Help options:",
@@ -337,7 +336,6 @@ gst_init_check_with_popt_table (int *argc, char **argv[],
     GST_DEBUG ("already initialized gst");
     return TRUE;
   }
-
   if (!argc || !argv) {
     if (argc || argv)
       g_warning ("gst_init: Only one of argc or argv was NULL");
@@ -346,7 +344,6 @@ gst_init_check_with_popt_table (int *argc, char **argv[],
       return FALSE;
     if (!init_post ())
       return FALSE;
-    gst_initialized = TRUE;
     return TRUE;
   }
 
@@ -358,11 +355,6 @@ gst_init_check_with_popt_table (int *argc, char **argv[],
   context = poptGetContext ("GStreamer", *argc, (const char **) *argv,
       options, 0);
 
-  /* check for GST_DEBUG environment variable */
-  gst_debug_env = g_getenv ("GST_DEBUG");
-  if (gst_debug_env)
-    parse_debug_list (gst_debug_env);
-
   /* Scan until we reach the end (-1), ignoring errors */
   while ((nextopt = poptGetNextOpt (context)) != -1) {
 
@@ -409,17 +401,24 @@ load_plugin_func (gpointer data, gpointer user_data)
 {
   GstPlugin *plugin;
   const gchar *filename;
+  GError *err = NULL;
 
   filename = (const gchar *) data;
 
-  plugin = gst_plugin_load_file (filename, NULL);
+  plugin = gst_plugin_load_file (filename, &err);
 
   if (plugin) {
     GST_INFO ("Loaded plugin: \"%s\"", filename);
 
     gst_registry_pool_add_plugin (plugin);
   } else {
-    GST_WARNING ("Failed to load plugin: \"%s\"", filename);
+    if (err) {
+      /* Report error to user, and free error */
+      GST_ERROR ("Failed to load plugin: %s\n", err->message);
+      g_error_free (err);
+    } else {
+      GST_WARNING ("Failed to load plugin: \"%s\"", filename);
+    }
   }
 
   g_free (data);
@@ -469,16 +468,24 @@ init_pre (void)
   bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 #endif /* ENABLE_NLS */
 
-#ifndef GST_DISABLE_REGISTRY
   {
     const gchar *debug_list;
 
     debug_list = g_getenv ("GST_DEBUG");
     if (debug_list) {
       parse_debug_list (debug_list);
+
+      if (g_getenv ("GST_DEBUGNOCOLOR"))
+        gst_debug_set_colored (FALSE);
+
     }
   }
-#endif
+
+  /* This is the earliest we can make stuff show up in the logs.
+   * So give some useful info about GStreamer here */
+  GST_INFO ("Initializing GStreamer Core Library version %s", VERSION);
+  GST_INFO ("Using library from %s", LIBDIR);
+
 #ifndef GST_DISABLE_REGISTRY
   {
     gchar *user_reg;
@@ -526,7 +533,7 @@ gst_register_core_elements (GstPlugin * plugin)
           GST_TYPE_PIPELINE) ||
       !gst_element_register (plugin, "thread", GST_RANK_PRIMARY,
           GST_TYPE_THREAD) ||
-      !gst_element_register (plugin, "queue", GST_RANK_PRIMARY, GST_TYPE_QUEUE))
+      !gst_element_register (plugin, "queue", GST_RANK_NONE, GST_TYPE_QUEUE))
     g_assert_not_reached ();
 
   return TRUE;
@@ -571,11 +578,10 @@ init_post (void)
   llf = G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_ERROR | G_LOG_FLAG_FATAL;
   g_log_set_handler (g_log_domain_gstreamer, llf, debug_log_handler, NULL);
 
-  GST_INFO ("Initializing GStreamer Core Library version %s", VERSION);
-
   _gst_format_initialize ();
   _gst_query_type_initialize ();
   gst_object_get_type ();
+  gst_probe_get_type ();
   gst_pad_get_type ();
   gst_real_pad_get_type ();
   gst_ghost_pad_get_type ();
@@ -609,6 +615,7 @@ init_post (void)
   _gst_buffer_initialize ();
   _gst_tag_initialize ();
 
+  gst_initialized = TRUE;
 #ifndef GST_DISABLE_REGISTRY
   if (!_gst_registry_fixed) {
     /* don't override command-line options */
@@ -799,7 +806,6 @@ init_popt_callback (poptContext context, enum poptCallbackReason reason,
     case POPT_CALLBACK_REASON_POST:
       if (!init_post ())
         _gst_initialization_failure = TRUE;
-      gst_initialized = TRUE;
       break;
   }
 }
@@ -808,8 +814,9 @@ init_popt_callback (poptContext context, enum poptCallbackReason reason,
  * gst_use_threads:
  * @use_threads: a #gboolean indicating whether threads should be used
  *
- * This function is deprecated and should not be used in new code.
- * GStreamer requires threads to be enabled at all times.
+ * Does nothing anymore. GStreamer requires threads to be enabled at all times.
+ *
+ * Deprecated: This function is deprecated and should not be used in new code.
  */
 void
 gst_use_threads (gboolean use_threads)
@@ -819,11 +826,10 @@ gst_use_threads (gboolean use_threads)
 /**
  * gst_has_threads:
  *
- * This function is deprecated and should not be used in new code.
- *
  * Queries if GStreamer has threads enabled.
  *
  * Returns: %TRUE if threads are enabled.
+ * Deprecated: This function is deprecated and should not be used in new code.
  */
 gboolean
 gst_has_threads (void)
