@@ -33,6 +33,7 @@
 #include "gstscheduler.h"
 #include "gstindex.h"
 #include "gstutils.h"
+#include "gstchildproxy.h"
 
 GST_DEBUG_CATEGORY_STATIC (bin_debug);
 #define GST_CAT_DEFAULT bin_debug
@@ -97,6 +98,7 @@ enum
 static void gst_bin_base_init (gpointer g_class);
 static void gst_bin_class_init (GstBinClass * klass);
 static void gst_bin_init (GstBin * bin);
+static void gst_bin_child_proxy_init (gpointer g_iface, gpointer iface_data);
 
 static GstElementClass *parent_class = NULL;
 static guint gst_bin_signals[LAST_SIGNAL] = { 0 };
@@ -123,9 +125,18 @@ gst_bin_get_type (void)
       NULL
     };
 
+    static const GInterfaceInfo child_proxy_info = {
+      gst_bin_child_proxy_init,
+      NULL,
+      NULL
+    };
+
     _gst_bin_type =
         g_type_register_static (GST_TYPE_ELEMENT, "GstBin", &bin_info, 0);
 
+    g_type_add_interface_static (_gst_bin_type, GST_TYPE_CHILD_PROXY,
+        &child_proxy_info);
+
     GST_DEBUG_CATEGORY_INIT (bin_debug, "bin", GST_DEBUG_BOLD,
         "debugging info for the 'bin' container element");
   }
@@ -213,6 +224,28 @@ gst_bin_init (GstBin * bin)
   bin->children = NULL;
 }
 
+static GstObject *
+gst_bin_child_proxy_get_child_by_index (GstChildProxy * child_proxy,
+    guint index)
+{
+  return g_list_nth_data (GST_BIN (child_proxy)->children, index);
+}
+
+guint
+gst_bin_child_proxy_get_children_count (GstChildProxy * child_proxy)
+{
+  return GST_BIN (child_proxy)->numchildren;
+}
+
+static void
+gst_bin_child_proxy_init (gpointer g_iface, gpointer iface_data)
+{
+  GstChildProxyInterface *iface = g_iface;
+
+  iface->get_children_count = gst_bin_child_proxy_get_children_count;
+  iface->get_child_by_index = gst_bin_child_proxy_get_child_by_index;
+}
+
 /**
  * gst_bin_new:
  * @name: name of new bin
@@ -529,6 +562,7 @@ gst_bin_add (GstBin * bin, GstElement * element)
 
   if (bclass->add_element) {
     bclass->add_element (bin, element);
+    gst_child_proxy_child_added (GST_OBJECT (bin), GST_OBJECT (element));
   } else {
     GST_ELEMENT_ERROR (bin, CORE, FAILED, (NULL),
         ("cannot add element %s to bin %s",
@@ -555,6 +589,9 @@ gst_bin_remove_func (GstBin * bin, GstElement * element)
   /* remove this element from the list of managed elements */
   gst_bin_unset_element_sched (element, GST_ELEMENT_SCHED (bin));
 
+  /* if it is still iterating, make it stop */
+  gst_element_release_locks (element);
+
   /* now remove the element from the list of elements */
   bin->children = g_list_remove (bin->children, element);
   bin->numchildren--;
@@ -617,6 +654,7 @@ gst_bin_remove (GstBin * bin, GstElement * element)
   bclass = GST_BIN_GET_CLASS (bin);
 
   if (bclass->remove_element) {
+    gst_child_proxy_child_removed (GST_OBJECT (bin), GST_OBJECT (element));
     bclass->remove_element (bin, element);
   } else {
     g_warning ("cannot remove elements from bin %s\n", GST_ELEMENT_NAME (bin));
@@ -708,7 +746,11 @@ gst_bin_child_state_change_func (GstBin * bin, GstElementState oldstate,
     if (bin->child_states[i] != 0) {
       gint state = (1 << i);
 
-      if (GST_STATE (bin) != state) {
+      /* We only change state on the parent if the state is not locked.
+       * State locking can occur if the bin itself set state on children,
+       * which should not recurse since it leads to infinite loops. */
+      if (GST_STATE (bin) != state &&
+          !GST_FLAG_IS_SET (bin, GST_BIN_STATE_LOCKED)) {
         GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, bin,
             "highest child state is %s, changing bin state accordingly",
             gst_element_state_get_name (state));
@@ -832,7 +874,6 @@ gst_bin_change_state (GstElement * element)
   GstBin *bin;
   GstElementStateReturn ret;
   GstElementState old_state, pending;
-  SetKidStateData data;
 
   g_return_val_if_fail (GST_IS_BIN (element), GST_STATE_FAILURE);
 
@@ -849,27 +890,43 @@ gst_bin_change_state (GstElement * element)
   if (pending == GST_STATE_VOID_PENDING)
     return GST_STATE_SUCCESS;
 
-  data.pending = pending;
-  data.result = GST_STATE_SUCCESS;
-  if (!gst_bin_foreach (bin, set_kid_state_func, &data)) {
-    GST_STATE_PENDING (element) = old_state;
-    return GST_STATE_FAILURE;
+  /* If we're changing state non-recursively (see _norecurse()),
+   * this flag is already set and we should not set children states. */
+  if (!GST_FLAG_IS_SET (bin, GST_BIN_STATE_LOCKED)) {
+    SetKidStateData data;
+
+    /* So now we use this flag to make sure that kids don't re-set our
+     * state, which would lead to infinite loops. */
+    GST_FLAG_SET (bin, GST_BIN_STATE_LOCKED);
+    data.pending = pending;
+    data.result = GST_STATE_SUCCESS;
+    if (!gst_bin_foreach (bin, set_kid_state_func, &data)) {
+      GST_FLAG_UNSET (bin, GST_BIN_STATE_LOCKED);
+      GST_STATE_PENDING (element) = old_state;
+      return GST_STATE_FAILURE;
+    }
+    GST_FLAG_UNSET (bin, GST_BIN_STATE_LOCKED);
+
+    GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, element,
+        "done changing bin's state from %s to %s, now in %s",
+        gst_element_state_get_name (old_state),
+        gst_element_state_get_name (pending),
+        gst_element_state_get_name (GST_STATE (element)));
+
+    /* if we're async, the kids will change state later (when the
+     * lock-state flag is no longer held) and all will be fine. */
+    if (data.result == GST_STATE_ASYNC)
+      return GST_STATE_ASYNC;
+  } else {
+    GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, element,
+        "Not recursing state change onto children");
   }
 
-  GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, element,
-      "done changing bin's state from %s to %s, now in %s",
-      gst_element_state_get_name (old_state),
-      gst_element_state_get_name (pending),
-      gst_element_state_get_name (GST_STATE (element)));
-
-  if (data.result == GST_STATE_ASYNC)
-    ret = GST_STATE_ASYNC;
-  else {
-    /* FIXME: this should have been done by the children already, no? */
-    if (parent_class->change_state) {
-      ret = parent_class->change_state (element);
-    } else
-      ret = GST_STATE_SUCCESS;
+  /* FIXME: this should have been done by the children already, no? */
+  if (parent_class->change_state) {
+    ret = parent_class->change_state (element);
+  } else {
+    ret = GST_STATE_SUCCESS;
   }
   return ret;
 }
@@ -900,9 +957,13 @@ gst_bin_change_state_norecurse (GstBin * bin)
 {
   GstElementStateReturn ret;
 
-  if (parent_class->change_state) {
+  if (GST_ELEMENT_GET_CLASS (bin)->change_state) {
     GST_CAT_LOG_OBJECT (GST_CAT_STATES, bin, "setting bin's own state");
-    ret = parent_class->change_state (GST_ELEMENT (bin));
+
+    /* Non-recursive state change flag */
+    GST_FLAG_SET (bin, GST_BIN_STATE_LOCKED);
+    ret = GST_ELEMENT_GET_CLASS (bin)->change_state (GST_ELEMENT (bin));
+    GST_FLAG_UNSET (bin, GST_BIN_STATE_LOCKED);
 
     return ret;
   } else
@@ -1154,7 +1215,7 @@ gst_bin_save_thyself (GstObject * object, xmlNodePtr parent)
   if (GST_OBJECT_CLASS (parent_class)->save_thyself)
     GST_OBJECT_CLASS (parent_class)->save_thyself (GST_OBJECT (bin), parent);
 
-  childlist = xmlNewChild (parent, NULL, "children", NULL);
+  childlist = xmlNewChild (parent, NULL, (guchar *) "children", NULL);
 
   GST_CAT_INFO (GST_CAT_XML, "[%s]: saving %d children",
       GST_ELEMENT_NAME (bin), bin->numchildren);
@@ -1162,7 +1223,7 @@ gst_bin_save_thyself (GstObject * object, xmlNodePtr parent)
   children = bin->children;
   while (children) {
     child = GST_ELEMENT (children->data);
-    elementnode = xmlNewChild (childlist, NULL, "element", NULL);
+    elementnode = xmlNewChild (childlist, NULL, (guchar *) "element", NULL);
     gst_object_save_thyself (GST_OBJECT (child), elementnode);
     children = g_list_next (children);
   }
@@ -1177,12 +1238,12 @@ gst_bin_restore_thyself (GstObject * object, xmlNodePtr self)
   xmlNodePtr childlist;
 
   while (field) {
-    if (!strcmp (field->name, "children")) {
+    if (!strcmp ((char *) field->name, "children")) {
       GST_CAT_INFO (GST_CAT_XML, "[%s]: loading children",
           GST_ELEMENT_NAME (object));
       childlist = field->xmlChildrenNode;
       while (childlist) {
-        if (!strcmp (childlist->name, "element")) {
+        if (!strcmp ((char *) childlist->name, "element")) {
           GstElement *element =
               gst_xml_make_element (childlist, GST_OBJECT (bin));
 
