@@ -27,6 +27,9 @@
 #include "gstregistrypool.h"
 #include "gstinfo.h"
 #include "gsturi.h"
+#ifndef GST_DISABLE_REGISTRY
+#include "registries/gstxmlregistry.h"  /* g_critical in gst_element_factory_create */
+#endif
 
 GST_DEBUG_CATEGORY_STATIC (element_factory_debug);
 #define GST_CAT_DEFAULT element_factory_debug
@@ -133,14 +136,25 @@ __gst_element_details_clear (GstElementDetails * dp)
   dp->author = NULL;
 }
 
+#define VALIDATE_SET(__dest, __src, __entry)				\
+G_STMT_START {								\
+  if (g_utf8_validate (__src->__entry, -1, NULL)) {			\
+    __dest->__entry = g_strdup (__src->__entry);			\
+  } else {								\
+    g_warning ("Invalid UTF-8 in " G_STRINGIFY (__entry) ": %s",	\
+        __src->__entry);						\
+    __dest->__entry = g_strdup ("[ERROR: invalid UTF-8]");		\
+  }									\
+} G_STMT_END
+
 void
 __gst_element_details_set (GstElementDetails * dest,
     const GstElementDetails * src)
 {
-  dest->longname = g_strdup (src->longname);
-  dest->klass = g_strdup (src->klass);
-  dest->description = g_strdup (src->description);
-  dest->author = g_strdup (src->author);
+  VALIDATE_SET (dest, src, longname);
+  VALIDATE_SET (dest, src, klass);
+  VALIDATE_SET (dest, src, description);
+  VALIDATE_SET (dest, src, author);
 }
 
 void
@@ -150,12 +164,12 @@ __gst_element_details_copy (GstElementDetails * dest,
   __gst_element_details_clear (dest);
   __gst_element_details_set (dest, src);
 }
+
 static void
 gst_element_factory_cleanup (GstElementFactory * factory)
 {
   __gst_element_details_clear (&factory->details);
   if (factory->type) {
-    g_type_class_unref (g_type_class_peek (factory->type));
     factory->type = 0;
   }
 
@@ -201,25 +215,30 @@ gst_element_register (GstPlugin * plugin, const gchar * name, guint rank,
   factory = gst_element_factory_find (name);
 
   if (!factory) {
-    klass = GST_ELEMENT_CLASS (g_type_class_ref (type));
     factory =
         GST_ELEMENT_FACTORY (g_object_new (GST_TYPE_ELEMENT_FACTORY, NULL));
     gst_plugin_feature_set_name (GST_PLUGIN_FEATURE (factory), name);
     GST_LOG_OBJECT (factory, "Created new elementfactory for type %s",
         g_type_name (type));
+    gst_plugin_add_feature (plugin, GST_PLUGIN_FEATURE (factory));
   } else {
     g_return_val_if_fail (factory->type == 0, FALSE);
-    klass = GST_ELEMENT_CLASS (g_type_class_ref (type));
     gst_element_factory_cleanup (factory);
     GST_LOG_OBJECT (factory, "Reuse existing elementfactory for type %s",
         g_type_name (type));
   }
 
+  klass = GST_ELEMENT_CLASS (g_type_class_ref (type));
   factory->type = type;
+  if (!GST_IS_ELEMENT_DETAILS (&klass->details)) {
+    g_warning ("invalid element details in class %s", g_type_name (type));
+    goto error;
+  }
   __gst_element_details_copy (&factory->details, &klass->details);
   factory->padtemplates = g_list_copy (klass->padtemplates);
   g_list_foreach (factory->padtemplates, (GFunc) gst_object_ref, NULL);
   factory->numpadtemplates = klass->numpadtemplates;
+  klass->elementfactory = factory;
 
   /* special stuff for URI handling */
   if (g_type_is_a (type, GST_TYPE_URI_HANDLER)) {
@@ -243,12 +262,13 @@ gst_element_register (GstPlugin * plugin, const gchar * name, guint rank,
   g_free (interfaces);
 
   gst_plugin_feature_set_rank (GST_PLUGIN_FEATURE (factory), rank);
-  gst_plugin_add_feature (plugin, GST_PLUGIN_FEATURE (factory));
 
+  g_type_class_unref (klass);
   return TRUE;
 
 error:
   gst_element_factory_cleanup (factory);
+  g_type_class_unref (klass);
   return FALSE;
 }
 
@@ -283,8 +303,19 @@ gst_element_factory_create (GstElementFactory * factory, const gchar * name)
     GST_INFO ("creating \"%s\"", GST_PLUGIN_FEATURE_NAME (factory));
 
   if (factory->type == 0) {
+#ifndef GST_DISABLE_REGISTRY
+    GstPlugin *plugin = GST_PLUGIN_FEATURE (factory)->manager;
+
+    g_critical
+        ("Factory for `%s' has no type. This probably means the plugin wasn't found because the registry is broken. The plugin GStreamer was looking for is named '%s' and is expected in file '%s'. The registry for this plugin is located at '%s'",
+        GST_PLUGIN_FEATURE_NAME (factory),
+        gst_plugin_get_name (plugin), gst_plugin_get_filename (plugin),
+        GST_IS_XML_REGISTRY (plugin->manager) ? GST_XML_REGISTRY (plugin->
+            manager)->location : "Unknown");
+#else
     g_critical ("Factory for `%s' has no type",
         GST_PLUGIN_FEATURE_NAME (factory));
+#endif
     return NULL;
   }
 
@@ -293,13 +324,11 @@ gst_element_factory_create (GstElementFactory * factory, const gchar * name)
     oclass->elementfactory = factory;
 
   /* create an instance of the element */
-  element = GST_ELEMENT (g_object_new (factory->type, NULL));
+  element = GST_ELEMENT (g_object_new (factory->type, "name", name, NULL));
   g_assert (element != NULL);
 
   g_type_class_unref (oclass);
 
-  gst_object_set_name (GST_OBJECT (element), name);
-
   return element;
 }
 
@@ -596,7 +625,6 @@ gst_element_factory_unload_thyself (GstPluginFeature * feature)
   factory = GST_ELEMENT_FACTORY (feature);
 
   if (factory->type) {
-    g_type_class_unref (g_type_class_peek (factory->type));
     factory->type = 0;
   }
 }
