@@ -623,8 +623,7 @@ gst_index_add_entry (GstIndex * index, GstIndexEntry * entry)
  * @id: the id of the index writer
  * @flags: optinal flags for this entry
  * @n: number of associations
- * @list: list of associations
- * @...: other format/value pairs or 0 to end the list
+ * @list: list of format/value associations pais
  *
  * Associate given format/value pairs with each other.
  *
@@ -914,11 +913,12 @@ gst_index_factory_new (const gchar * name, const gchar * longdesc, GType type)
   factory = gst_index_factory_find (name);
   if (!factory) {
     factory = GST_INDEX_FACTORY (g_object_new (GST_TYPE_INDEX_FACTORY, NULL));
+    GST_PLUGIN_FEATURE_NAME (factory) = g_strdup (name);
+  } else {
+    g_object_ref (G_OBJECT (factory));
   }
 
-  GST_PLUGIN_FEATURE_NAME (factory) = g_strdup (name);
-  if (factory->longdesc)
-    g_free (factory->longdesc);
+  g_free (factory->longdesc);
   factory->longdesc = g_strdup (longdesc);
   factory->type = type;
 
