@@ -32,7 +32,7 @@
 
 G_BEGIN_DECLS
 
-extern GType _gst_object_type;
+GST_EXPORT GType _gst_object_type;
 
 #define GST_TYPE_OBJECT			(_gst_object_type)
 #define GST_IS_OBJECT(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_OBJECT))
@@ -132,9 +132,11 @@ gboolean	gst_object_check_uniqueness	(GList *list, const gchar *name);
 xmlNodePtr	gst_object_save_thyself		(GstObject *object, xmlNodePtr parent);
 void		gst_object_restore_thyself	(GstObject *object, xmlNodePtr self);
 #else
+#if defined _GNUC_ && _GNUC_ >= 3
 #pragma GCC poison gst_object_save_thyself
 #pragma GCC poison gst_object_restore_thyself
 #endif
+#endif
 
 /* refcounting + life cycle */
 GstObject *	gst_object_ref			(GstObject *object);
@@ -157,8 +159,10 @@ void		gst_class_signal_emit_by_name	(GstObject	*object,
 		                                 const gchar	*name,
 						 xmlNodePtr 	 self);
 #else
+#if defined _GNUC_ && _GNUC_ >= 3
 #pragma GCC poison gst_class_signal_emit_by_name
 #endif
+#endif
 
 
 G_END_DECLS
