@@ -15,7 +15,8 @@ typedef struct
   gchar *bs_accesspattern;
 
   gboolean integrity_check;
-} TestParam;
+}
+TestParam;
 
 static GSList *params = NULL;
 
@@ -67,7 +68,7 @@ read_param_file (gchar * filename)
   gchar *scan_str;
   gboolean res = TRUE;
 
-  fp = fopen (filename, "r");
+  fp = fopen (filename, "rb");
   if (fp == NULL)
     return FALSE;
 
@@ -189,9 +190,9 @@ main (int argc, char *argv[])
   bs = gst_element_factory_make ("bstest", "bs");
   g_assert (bs);
 
-  gst_element_link_many (src, bs, sink);
+  gst_element_link_many (src, bs, sink, NULL);
 
-  gst_bin_add_many (GST_BIN (pipeline), src, bs, sink);
+  gst_bin_add_many (GST_BIN (pipeline), src, bs, sink, NULL);
 
   walk = params;
 
