@@ -6,6 +6,7 @@
 #include <gst/control/control.h>
 #include <string.h>
 #include <locale.h>
+#include <glib/gprintf.h>
 
 #define PUT_START_TAG(pfx,tag)                                  \
 G_STMT_START{                                                   \
@@ -43,10 +44,24 @@ G_STMT_START{                                                   \
   g_print ("%*.*s"str"\n", pfx, pfx, "" , ##a);	   		\
 }G_STMT_END
 
+#else
+
+static inline void
+PUT_STRING (int pfx, const char *format, ...)
+{
+  va_list varargs;
+
+  g_print ("%*.*s", pfx, pfx, "");
+  va_start (varargs, format);
+  g_vprintf (format, varargs);
+  va_end (varargs);
+  g_print ("\n");
+}
+
 #endif
 
 static void
-print_caps (const GstCaps *caps, gint pfx)
+print_caps (const GstCaps * caps, gint pfx)
 {
   char *s;
 
@@ -55,11 +70,11 @@ print_caps (const GstCaps *caps, gint pfx)
 
   s = gst_caps_to_string (caps);
   PUT_ESCAPED (pfx, "caps", s);
-  g_free(s);
+  g_free (s);
 }
 
 static void
-print_formats (const GstFormat *formats, gint pfx)
+print_formats (const GstFormat * formats, gint pfx)
 {
   while (formats && *formats) {
     const GstFormatDefinition *definition;
@@ -67,17 +82,16 @@ print_formats (const GstFormat *formats, gint pfx)
     definition = gst_format_get_details (*formats);
     if (definition)
       PUT_STRING (pfx, "<format id=\"%d\" nick=\"%s\">%s</format>",
-                  *formats, definition->nick, definition->description);
+          *formats, definition->nick, definition->description);
     else
-      PUT_STRING (pfx, "<format id=\"%d\">unknown</format>",
-                  *formats);
+      PUT_STRING (pfx, "<format id=\"%d\">unknown</format>", *formats);
 
     formats++;
   }
 }
 
 static void
-print_query_types (const GstQueryType *types, gint pfx)
+print_query_types (const GstQueryType * types, gint pfx)
 {
   while (types && *types) {
     const GstQueryTypeDefinition *definition;
@@ -85,17 +99,16 @@ print_query_types (const GstQueryType *types, gint pfx)
     definition = gst_query_type_get_details (*types);
     if (definition)
       PUT_STRING (pfx, "<query-type id=\"%d\" nick=\"%s\">%s</query-type>",
-                  *types, definition->nick, definition->description);
+          *types, definition->nick, definition->description);
     else
-      PUT_STRING (pfx, "<query-type id=\"%d\">unknown</query-type>",
-                  *types);
+      PUT_STRING (pfx, "<query-type id=\"%d\">unknown</query-type>", *types);
 
     types++;
   }
 }
 
 static void
-print_event_masks (const GstEventMask *masks, gint pfx)
+print_event_masks (const GstEventMask * masks, gint pfx)
 {
 #ifndef GST_DISABLE_ENUMTYPES
   GType event_type;
@@ -103,7 +116,7 @@ print_event_masks (const GstEventMask *masks, gint pfx)
   GType event_flags;
   GFlagsClass *flags_class = NULL;
 
-  event_type = gst_event_type_get_type();
+  event_type = gst_event_type_get_type ();
   klass = (GEnumClass *) g_type_class_ref (event_type);
 
   while (masks && masks->type) {
@@ -121,8 +134,7 @@ print_event_masks (const GstEventMask *masks, gint pfx)
     }
 
     value = g_enum_get_value (klass, masks->type);
-    PUT_STRING (pfx, "<event type=\"%s\">",
-                value->value_nick);
+    PUT_STRING (pfx, "<event type=\"%s\">", value->value_nick);
 
     while (flags) {
       GFlagsValue *value;
@@ -146,7 +158,7 @@ print_event_masks (const GstEventMask *masks, gint pfx)
 }
 
 static void
-output_hierarchy (GType type, gint level, gint *maxlevel)
+output_hierarchy (GType type, gint level, gint * maxlevel)
 {
   GType parent;
 
@@ -164,20 +176,21 @@ output_hierarchy (GType type, gint level, gint *maxlevel)
 }
 
 static void
-print_element_properties (GstElement *element, gint pfx)
+print_element_properties (GstElement * element, gint pfx)
 {
   GParamSpec **property_specs;
-  gint num_properties,i;
+  guint num_properties, i;
   gboolean readable;
 
   property_specs = g_object_class_list_properties
-                     (G_OBJECT_GET_CLASS (element), &num_properties);
+      (G_OBJECT_GET_CLASS (element), &num_properties);
 
   PUT_START_TAG (pfx, "element-properties");
 
   for (i = 0; i < num_properties; i++) {
     GValue value = { 0, };
     GParamSpec *param = property_specs[i];
+
     readable = FALSE;
 
     g_value_init (&value, param->value_type);
@@ -187,13 +200,12 @@ print_element_properties (GstElement *element, gint pfx)
     }
     PUT_START_TAG (pfx + 1, "element-property");
     PUT_ESCAPED (pfx + 2, "name", g_param_spec_get_name (param));
-    PUT_ESCAPED (pfx + 2, "type",  g_type_name (param->value_type));
+    PUT_ESCAPED (pfx + 2, "type", g_type_name (param->value_type));
     PUT_ESCAPED (pfx + 2, "nick", g_param_spec_get_nick (param));
     PUT_ESCAPED (pfx + 2, "blurb", g_param_spec_get_blurb (param));
     if (readable) {
       PUT_ESCAPED (pfx + 2, "flags", "RW");
-    }
-    else {
+    } else {
       PUT_ESCAPED (pfx + 2, "flags", "W");
     }
 
@@ -207,64 +219,74 @@ print_element_properties (GstElement *element, gint pfx)
       case G_TYPE_ULONG:
       {
         GParamSpecULong *pulong = G_PARAM_SPEC_ULONG (param);
+
         PUT_STRING (pfx + 2, "<range min=\"%lu\" max=\"%lu\"/>",
-                        pulong->minimum, pulong->maximum);
+            pulong->minimum, pulong->maximum);
         PUT_ESCAPED (pfx + 2, "default", g_strdup_value_contents (&value));
         break;
       }
       case G_TYPE_LONG:
       {
         GParamSpecLong *plong = G_PARAM_SPEC_LONG (param);
+
         PUT_STRING (pfx + 2, "<range min=\"%ld\" max=\"%ld\"/>",
-                        plong->minimum, plong->maximum);
+            plong->minimum, plong->maximum);
         PUT_ESCAPED (pfx + 2, "default", g_strdup_value_contents (&value));
         break;
       }
       case G_TYPE_UINT:
       {
         GParamSpecUInt *puint = G_PARAM_SPEC_UINT (param);
+
         PUT_STRING (pfx + 2, "<range min=\"%u\" max=\"%u\"/>",
-                        puint->minimum, puint->maximum);
+            puint->minimum, puint->maximum);
         PUT_ESCAPED (pfx + 2, "default", g_strdup_value_contents (&value));
         break;
       }
       case G_TYPE_INT:
       {
         GParamSpecInt *pint = G_PARAM_SPEC_INT (param);
+
         PUT_STRING (pfx + 2, "<range min=\"%d\" max=\"%d\"/>",
-                        pint->minimum, pint->maximum);
+            pint->minimum, pint->maximum);
         PUT_ESCAPED (pfx + 2, "default", g_strdup_value_contents (&value));
         break;
       }
       case G_TYPE_UINT64:
       {
         GParamSpecUInt64 *puint64 = G_PARAM_SPEC_UINT64 (param);
-        PUT_STRING (pfx + 2, "<range min=\"%"G_GUINT64_FORMAT"\" max=\"%"G_GUINT64_FORMAT"\"/>",
-                        puint64->minimum, puint64->maximum);
+
+        PUT_STRING (pfx + 2,
+            "<range min=\"%" G_GUINT64_FORMAT "\" max=\"%" G_GUINT64_FORMAT
+            "\"/>", puint64->minimum, puint64->maximum);
         PUT_ESCAPED (pfx + 2, "default", g_strdup_value_contents (&value));
         break;
       }
       case G_TYPE_INT64:
       {
         GParamSpecInt64 *pint64 = G_PARAM_SPEC_INT64 (param);
-        PUT_STRING (pfx + 2, "<range min=\"%"G_GINT64_FORMAT"\" max=\"%"G_GINT64_FORMAT"\"/>",
-                        pint64->minimum, pint64->maximum);
+
+        PUT_STRING (pfx + 2,
+            "<range min=\"%" G_GINT64_FORMAT "\" max=\"%" G_GINT64_FORMAT
+            "\"/>", pint64->minimum, pint64->maximum);
         PUT_ESCAPED (pfx + 2, "default", g_strdup_value_contents (&value));
         break;
       }
       case G_TYPE_FLOAT:
       {
         GParamSpecFloat *pfloat = G_PARAM_SPEC_FLOAT (param);
+
         PUT_STRING (pfx + 2, "<range min=\"%f\" max=\"%f\"/>",
-               pfloat->minimum, pfloat->maximum);
+            pfloat->minimum, pfloat->maximum);
         PUT_ESCAPED (pfx + 2, "default", g_strdup_value_contents (&value));
         break;
       }
       case G_TYPE_DOUBLE:
       {
         GParamSpecDouble *pdouble = G_PARAM_SPEC_DOUBLE (param);
+
         PUT_STRING (pfx + 2, "<range min=\"%g\" max=\"%g\"/>",
-               pdouble->minimum, pdouble->maximum);
+            pdouble->minimum, pdouble->maximum);
         PUT_ESCAPED (pfx + 2, "default", g_strdup_value_contents (&value));
         break;
       }
@@ -277,8 +299,7 @@ print_element_properties (GstElement *element, gint pfx)
           else {
             print_caps (caps, 2);
           }
-        }
-        else if (G_IS_PARAM_SPEC_ENUM (param)) {
+        } else if (G_IS_PARAM_SPEC_ENUM (param)) {
           GEnumValue *values;
           guint j = 0;
           gint enum_value;
@@ -297,12 +318,11 @@ print_element_properties (GstElement *element, gint pfx)
           j = 0;
           while (values[j].value_name) {
             PUT_STRING (pfx + 3, "<value value=\"%d\" nick=\"%s\"/>",
-                            values[j].value, values[j].value_nick);
+                values[j].value, values[j].value_nick);
             j++;
           }
           PUT_END_TAG (pfx + 2, "enum-values");
-        }
-        else if (G_IS_PARAM_SPEC_FLAGS (param)) {
+        } else if (G_IS_PARAM_SPEC_FLAGS (param)) {
           GFlagsValue *values;
           guint j = 0;
           gint flags_value;
@@ -316,14 +336,12 @@ print_element_properties (GstElement *element, gint pfx)
           j = 0;
           while (values[j].value_name) {
             PUT_STRING (pfx + 3, "<flag value=\"%d\" nick=\"%s\"/>",
-                            values[j].value, values[j].value_nick);
+                values[j].value, values[j].value_nick);
             j++;
           }
           PUT_END_TAG (pfx + 2, "flags");
-        }
-        else if (G_IS_PARAM_SPEC_OBJECT (param)) {
-          PUT_ESCAPED (pfx + 2, "object-type",
-                          g_type_name(param->value_type));
+        } else if (G_IS_PARAM_SPEC_OBJECT (param)) {
+          PUT_ESCAPED (pfx + 2, "object-type", g_type_name (param->value_type));
         }
         break;
     }
@@ -334,45 +352,46 @@ print_element_properties (GstElement *element, gint pfx)
 }
 
 static void
-print_element_dynparamaters (GstElement *element, gint pfx)
+print_element_dynparamaters (GstElement * element, gint pfx)
 {
-  GstDParamManager* dpman;
-  GParamSpec** specs;
+  GstDParamManager *dpman;
+  GParamSpec **specs;
   gint x;
 
   PUT_START_TAG (pfx, "dyn-params");
 
-  if((dpman = gst_dpman_get_manager (element))) {
+  if ((dpman = gst_dpman_get_manager (element))) {
     specs = gst_dpman_list_dparam_specs (dpman);
     for (x = 0; specs[x] != NULL; x++) {
       PUT_START_TAG (pfx + 1, "dyn-param");
 
       PUT_ESCAPED (pfx + 2, "name", g_param_spec_get_name (specs[x]));
-      PUT_ESCAPED (pfx + 2, "type",  g_type_name (specs[x]->value_type));
-      PUT_ESCAPED (pfx + 2, "nick",  g_param_spec_get_nick (specs[x]));
-      PUT_ESCAPED (pfx + 2, "blurb",  g_param_spec_get_blurb (specs[x]));
+      PUT_ESCAPED (pfx + 2, "type", g_type_name (specs[x]->value_type));
+      PUT_ESCAPED (pfx + 2, "nick", g_param_spec_get_nick (specs[x]));
+      PUT_ESCAPED (pfx + 2, "blurb", g_param_spec_get_blurb (specs[x]));
 
       switch (G_PARAM_SPEC_VALUE_TYPE (specs[x])) {
         case G_TYPE_INT64:
-          PUT_STRING (pfx + 2, "<range min=\"%"G_GINT64_FORMAT"\" max=\"%"G_GINT64_FORMAT"\"/>",
-                      ((GParamSpecInt64 *) specs[x])->minimum,
-                      ((GParamSpecInt64 *) specs[x])->maximum);
-          PUT_STRING (pfx + 2, "<default>%"G_GINT64_FORMAT"</default>",
-                      ((GParamSpecInt64 *) specs[x])->default_value);
+          PUT_STRING (pfx + 2,
+              "<range min=\"%" G_GINT64_FORMAT "\" max=\"%" G_GINT64_FORMAT
+              "\"/>", ((GParamSpecInt64 *) specs[x])->minimum,
+              ((GParamSpecInt64 *) specs[x])->maximum);
+          PUT_STRING (pfx + 2, "<default>%" G_GINT64_FORMAT "</default>",
+              ((GParamSpecInt64 *) specs[x])->default_value);
           break;
         case G_TYPE_INT:
           PUT_STRING (pfx + 2, "<range min=\"%d\" max=\"%d\"/>",
-                      ((GParamSpecInt *) specs[x])->minimum,
-                      ((GParamSpecInt *) specs[x])->maximum);
+              ((GParamSpecInt *) specs[x])->minimum,
+              ((GParamSpecInt *) specs[x])->maximum);
           PUT_STRING (pfx + 2, "<default>%d</default>",
-                      ((GParamSpecInt *) specs[x])->default_value);
+              ((GParamSpecInt *) specs[x])->default_value);
           break;
         case G_TYPE_FLOAT:
           PUT_STRING (pfx + 2, "<range min=\"%f\" max=\"%f\"/>",
-            ((GParamSpecFloat *) specs[x])->minimum,
-            ((GParamSpecFloat *) specs[x])->maximum);
+              ((GParamSpecFloat *) specs[x])->minimum,
+              ((GParamSpecFloat *) specs[x])->maximum);
           PUT_STRING (pfx + 2, "<default>%f</default>",
-            ((GParamSpecFloat *) specs[x])->default_value);
+              ((GParamSpecFloat *) specs[x])->default_value);
           break;
         default:
           break;
@@ -385,7 +404,7 @@ print_element_dynparamaters (GstElement *element, gint pfx)
 }
 
 static void
-print_element_signals (GstElement *element, gint pfx)
+print_element_signals (GstElement * element, gint pfx)
 {
   guint *signals;
   guint nsignals;
@@ -407,11 +426,11 @@ print_element_signals (GstElement *element, gint pfx)
       const GType *param_types;
       gint j;
 
-      query = g_new0 (GSignalQuery,1);
+      query = g_new0 (GSignalQuery, 1);
       g_signal_query (signals[i], query);
 
       if ((k == 0 && !(query->signal_flags & G_SIGNAL_ACTION)) ||
-          (k == 1 &&  (query->signal_flags & G_SIGNAL_ACTION))) {
+          (k == 1 && (query->signal_flags & G_SIGNAL_ACTION))) {
         n_params = query->n_params;
         return_type = query->return_type;
         param_types = query->param_types;
@@ -419,7 +438,8 @@ print_element_signals (GstElement *element, gint pfx)
         PUT_START_TAG (pfx + 1, "signal");
         PUT_ESCAPED (pfx + 2, "name", query->signal_name);
         PUT_ESCAPED (pfx + 2, "return-type", g_type_name (return_type));
-        PUT_ESCAPED (pfx + 2, "object-type", g_type_name (G_OBJECT_TYPE (element)));
+        PUT_ESCAPED (pfx + 2, "object-type",
+            g_type_name (G_OBJECT_TYPE (element)));
 
         PUT_START_TAG (pfx + 2, "params");
         for (j = 0; j < n_params; j++) {
@@ -443,7 +463,7 @@ print_element_signals (GstElement *element, gint pfx)
 }
 
 static gint
-print_element_info (GstElementFactory *factory)
+print_element_info (GstElementFactory * factory)
 {
   GstElement *element;
   GstObjectClass *gstobject_class;
@@ -468,10 +488,10 @@ print_element_info (GstElementFactory *factory)
   gstelement_class = GST_ELEMENT_CLASS (G_OBJECT_GET_CLASS (element));
 
   PUT_START_TAG (1, "details");
-  PUT_ESCAPED (2, "long-name",  factory->details.longname);
-  PUT_ESCAPED (2, "class",      factory->details.klass);
-  PUT_ESCAPED (2, "description",factory->details.description);
-  PUT_ESCAPED (2, "authors",    factory->details.author);
+  PUT_ESCAPED (2, "long-name", factory->details.longname);
+  PUT_ESCAPED (2, "class", factory->details.klass);
+  PUT_ESCAPED (2, "description", factory->details.description);
+  PUT_ESCAPED (2, "authors", factory->details.author);
   PUT_END_TAG (1, "details");
 
   output_hierarchy (G_OBJECT_TYPE (element), 0, &maxlevel);
@@ -480,18 +500,18 @@ print_element_info (GstElementFactory *factory)
   if (factory->numpadtemplates) {
     pads = factory->padtemplates;
     while (pads) {
-      padtemplate = (GstPadTemplate*)(pads->data);
-      pads = g_list_next(pads);
+      padtemplate = (GstPadTemplate *) (pads->data);
+      pads = g_list_next (pads);
 
       PUT_START_TAG (2, "pad-template");
-      PUT_ESCAPED (3, "name",   padtemplate->name_template);
+      PUT_ESCAPED (3, "name", padtemplate->name_template);
 
       if (padtemplate->direction == GST_PAD_SRC)
         PUT_ESCAPED (3, "direction", "src");
       else if (padtemplate->direction == GST_PAD_SINK)
         PUT_ESCAPED (3, "direction", "sink");
       else
-        PUT_ESCAPED (3, "direction", "unkown");
+        PUT_ESCAPED (3, "direction", "unknown");
 
       if (padtemplate->presence == GST_PAD_ALWAYS)
         PUT_ESCAPED (3, "presence", "always");
@@ -499,11 +519,10 @@ print_element_info (GstElementFactory *factory)
         PUT_ESCAPED (3, "presence", "sometimes");
       else if (padtemplate->presence == GST_PAD_REQUEST) {
         PUT_ESCAPED (3, "presence", "request");
-        PUT_ESCAPED (3, "request-function", 
-                        GST_DEBUG_FUNCPTR_NAME (gstelement_class->request_new_pad));
-      }
-      else
-        PUT_ESCAPED (3, "presence", "unkown");
+        PUT_ESCAPED (3, "request-function",
+            GST_DEBUG_FUNCPTR_NAME (gstelement_class->request_new_pad));
+      } else
+        PUT_ESCAPED (3, "presence", "unknown");
 
       if (padtemplate->caps) {
         print_caps (padtemplate->caps, 3);
@@ -547,16 +566,16 @@ print_element_info (GstElementFactory *factory)
   PUT_START_TAG (1, "element-implementation");
   if (element->loopfunc)
     PUT_STRING (2, "<loop-based function=\"%s\"/>",
-            GST_DEBUG_FUNCPTR_NAME (element->loopfunc));
+        GST_DEBUG_FUNCPTR_NAME (element->loopfunc));
 
   PUT_STRING (2, "<state-change function=\"%s\"/>",
-          GST_DEBUG_FUNCPTR_NAME (gstelement_class->change_state));
+      GST_DEBUG_FUNCPTR_NAME (gstelement_class->change_state));
 
 #ifndef GST_DISABLE_LOADSAVE
   PUT_STRING (2, "<save function=\"%s\"/>",
-          GST_DEBUG_FUNCPTR_NAME (gstobject_class->save_thyself));
+      GST_DEBUG_FUNCPTR_NAME (gstobject_class->save_thyself));
   PUT_STRING (2, "<load function=\"%s\"/>",
-          GST_DEBUG_FUNCPTR_NAME (gstobject_class->restore_thyself));
+      GST_DEBUG_FUNCPTR_NAME (gstobject_class->restore_thyself));
 #endif
   PUT_END_TAG (1, "element-implementation");
 
@@ -582,6 +601,7 @@ print_element_info (GstElementFactory *factory)
   PUT_START_TAG (1, "pads");
   if (element->numpads) {
     const GList *pads;
+
     pads = gst_element_get_pad_list (element);
     while (pads) {
       pad = GST_PAD (pads->data);
@@ -589,64 +609,63 @@ print_element_info (GstElementFactory *factory)
       realpad = GST_PAD_REALIZE (pad);
 
       PUT_START_TAG (2, "pad");
-      PUT_ESCAPED (3, "name",   gst_pad_get_name (pad));
+      PUT_ESCAPED (3, "name", gst_pad_get_name (pad));
 
       if (gst_pad_get_direction (pad) == GST_PAD_SRC)
         PUT_ESCAPED (3, "direction", "src");
       else if (gst_pad_get_direction (pad) == GST_PAD_SINK)
         PUT_ESCAPED (3, "direction", "sink");
       else
-        PUT_ESCAPED (3, "direction", "unkown");
+        PUT_ESCAPED (3, "direction", "unknown");
 
       if (GST_IS_GHOST_PAD (pad))
         PUT_ESCAPED (3, "ghost", gst_pad_get_name (pad));
 
       if (pad->padtemplate)
-        PUT_ESCAPED (3, "template",
-                pad->padtemplate->name_template);
+        PUT_ESCAPED (3, "template", pad->padtemplate->name_template);
 
       PUT_START_TAG (3, "implementation");
       if (realpad->chainfunc)
         PUT_STRING (4, "<chain-based function=\"%s\"/>",
-                GST_DEBUG_FUNCPTR_NAME (realpad->chainfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->chainfunc));
       if (realpad->getfunc)
         PUT_STRING (4, "<get-based function=\"%s\"/>",
-                GST_DEBUG_FUNCPTR_NAME (realpad->getfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->getfunc));
       if (realpad->formatsfunc != gst_pad_get_formats_default) {
         PUT_STRING (4, "<formats-function function=\"%s\">",
-                GST_DEBUG_FUNCPTR_NAME (realpad->formatsfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->formatsfunc));
         print_formats (gst_pad_get_formats (GST_PAD (realpad)), 5);
         PUT_END_TAG (4, "formats-function");
       }
       if (realpad->convertfunc != gst_pad_convert_default)
         PUT_STRING (4, "<convert-function function=\"%s\"/>",
-                GST_DEBUG_FUNCPTR_NAME (realpad->convertfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->convertfunc));
       if (realpad->eventfunc != gst_pad_event_default)
         PUT_STRING (4, "<event-function function=\"%s\"/>",
-                GST_DEBUG_FUNCPTR_NAME (realpad->eventfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->eventfunc));
       if (realpad->eventmaskfunc != gst_pad_get_event_masks_default) {
         PUT_STRING (4, "<event-mask-func function=\"%s\">",
-                GST_DEBUG_FUNCPTR_NAME (realpad->eventmaskfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->eventmaskfunc));
         print_event_masks (gst_pad_get_event_masks (GST_PAD (realpad)), 5);
         PUT_END_TAG (4, "event-mask-func");
       }
       if (realpad->queryfunc != gst_pad_query_default)
         PUT_STRING (4, "<query-function function=\"%s\"/>",
-                GST_DEBUG_FUNCPTR_NAME (realpad->queryfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->queryfunc));
       if (realpad->querytypefunc != gst_pad_get_query_types_default) {
         PUT_STRING (4, "<query-type-func function=\"%s\">",
-                GST_DEBUG_FUNCPTR_NAME (realpad->querytypefunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->querytypefunc));
         print_query_types (gst_pad_get_query_types (GST_PAD (realpad)), 5);
         PUT_END_TAG (4, "query-type-func");
       }
 
       if (realpad->intlinkfunc != gst_pad_get_internal_links_default)
         PUT_STRING (4, "<intlink-function function=\"%s\"/>",
-                GST_DEBUG_FUNCPTR_NAME(realpad->intlinkfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->intlinkfunc));
 
       if (realpad->bufferallocfunc)
         PUT_STRING (4, "<bufferalloc-function function=\"%s\"/>",
-                GST_DEBUG_FUNCPTR_NAME(realpad->bufferallocfunc));
+            GST_DEBUG_FUNCPTR_NAME (realpad->bufferallocfunc));
       PUT_END_TAG (3, "implementation");
 
       if (realpad->caps) {
@@ -683,12 +702,12 @@ print_element_list (void)
 {
   GList *plugins;
 
-  plugins = gst_registry_pool_plugin_list();
+  plugins = gst_registry_pool_plugin_list ();
   while (plugins) {
     GList *features;
     GstPlugin *plugin;
 
-    plugin = (GstPlugin*)(plugins->data);
+    plugin = (GstPlugin *) (plugins->data);
     plugins = g_list_next (plugins);
 
     features = gst_plugin_get_feature_list (plugin);
@@ -702,7 +721,7 @@ print_element_list (void)
 
         factory = GST_ELEMENT_FACTORY (feature);
         g_print ("%s:  %s: %s\n", plugin->desc.name,
-                GST_PLUGIN_FEATURE_NAME (factory) ,factory->details.longname);
+            GST_PLUGIN_FEATURE_NAME (factory), factory->details.longname);
       }
 #ifndef GST_DISABLE_INDEX
       else if (GST_IS_INDEX_FACTORY (feature)) {
@@ -710,34 +729,33 @@ print_element_list (void)
 
         factory = GST_INDEX_FACTORY (feature);
         g_print ("%s:  %s: %s\n", plugin->desc.name,
-                GST_PLUGIN_FEATURE_NAME (factory), factory->longdesc);
+            GST_PLUGIN_FEATURE_NAME (factory), factory->longdesc);
       }
 #endif
       else if (GST_IS_TYPE_FIND_FACTORY (feature)) {
         GstTypeFindFactory *factory;
 
-	factory = GST_TYPE_FIND_FACTORY (feature);
+        factory = GST_TYPE_FIND_FACTORY (feature);
         if (factory->extensions) {
-	  guint i = 0;
-	  g_print ("%s type: ", plugin->desc.name);
-	  while (factory->extensions[i]) {
-	    g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
-	    i++;
-	  }
-	} else
-	  g_print ("%s type: N/A\n", plugin->desc.name);
-      }
-      else if (GST_IS_SCHEDULER_FACTORY (feature)) {
+          guint i = 0;
+
+          g_print ("%s type: ", plugin->desc.name);
+          while (factory->extensions[i]) {
+            g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
+            i++;
+          }
+        } else
+          g_print ("%s type: N/A\n", plugin->desc.name);
+      } else if (GST_IS_SCHEDULER_FACTORY (feature)) {
         GstSchedulerFactory *factory;
 
         factory = GST_SCHEDULER_FACTORY (feature);
         g_print ("%s:  %s: %s\n", plugin->desc.name,
-                GST_PLUGIN_FEATURE_NAME (factory), factory->longdesc);
-      }
-      else {
+            GST_PLUGIN_FEATURE_NAME (factory), factory->longdesc);
+      } else {
         g_print ("%s:  %s (%s)\n", plugin->desc.name,
-                GST_PLUGIN_FEATURE_NAME (feature),
-                g_type_name (G_OBJECT_TYPE (feature)));
+            GST_PLUGIN_FEATURE_NAME (feature),
+            g_type_name (G_OBJECT_TYPE (feature)));
       }
 
       features = g_list_next (features);
@@ -746,7 +764,7 @@ print_element_list (void)
 }
 
 static void
-print_plugin_info (GstPlugin *plugin)
+print_plugin_info (GstPlugin * plugin)
 {
   GList *features;
   gint num_features = 0;
@@ -758,13 +776,13 @@ print_plugin_info (GstPlugin *plugin)
   gint num_other = 0;
 
   g_print ("Plugin Details:\n");
-  g_print ("  Name:\t\t%s\n",	    plugin->desc.name);
-  g_print ("  Description:\t%s\n",  plugin->desc.description);
-  g_print ("  Filename:\t%s\n",	    plugin->filename);
-  g_print ("  Version:\t%s\n",	    plugin->desc.version);
-  g_print ("  License:\t%s\n",	    plugin->desc.license);
-  g_print ("  Package:\t%s\n",	    plugin->desc.package);
-  g_print ("  Origin URL:\t%s\n",   plugin->desc.origin);
+  g_print ("  Name:\t\t%s\n", plugin->desc.name);
+  g_print ("  Description:\t%s\n", plugin->desc.description);
+  g_print ("  Filename:\t%s\n", plugin->filename);
+  g_print ("  Version:\t%s\n", plugin->desc.version);
+  g_print ("  License:\t%s\n", plugin->desc.license);
+  g_print ("  Package:\t%s\n", plugin->desc.package);
+  g_print ("  Origin URL:\t%s\n", plugin->desc.origin);
   g_print ("\n");
 
   features = gst_plugin_get_feature_list (plugin);
@@ -779,7 +797,7 @@ print_plugin_info (GstPlugin *plugin)
 
       factory = GST_ELEMENT_FACTORY (feature);
       g_print ("  %s: %s\n", GST_OBJECT_NAME (factory),
-              factory->details.longname);
+          factory->details.longname);
       num_elements++;
     }
 #ifndef GST_DISABLE_INDEX
@@ -796,26 +814,25 @@ print_plugin_info (GstPlugin *plugin)
 
       factory = GST_TYPE_FIND_FACTORY (feature);
       if (factory->extensions) {
-	guint i = 0;
-	g_print ("%s type: ", plugin->desc.name);
-	while (factory->extensions[i]) {
-	  g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
-	  i++;
-	}
+        guint i = 0;
+
+        g_print ("%s type: ", plugin->desc.name);
+        while (factory->extensions[i]) {
+          g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
+          i++;
+        }
       } else
-	g_print ("%s type: N/A\n", plugin->desc.name);
+        g_print ("%s type: N/A\n", plugin->desc.name);
       num_types++;
-    }
-    else if (GST_IS_SCHEDULER_FACTORY (feature)) {
+    } else if (GST_IS_SCHEDULER_FACTORY (feature)) {
       GstSchedulerFactory *factory;
 
       factory = GST_SCHEDULER_FACTORY (feature);
       g_print ("  %s: %s\n", GST_OBJECT_NAME (factory), factory->longdesc);
       num_schedulers++;
-    }
-    else {
+    } else {
       g_print ("  %s (%s)\n", gst_object_get_name (GST_OBJECT (feature)),
-                              g_type_name (G_OBJECT_TYPE (feature)));
+          g_type_name (G_OBJECT_TYPE (feature)));
       num_other++;
     }
     num_features++;
@@ -846,11 +863,12 @@ main (int argc, char *argv[])
   GstPlugin *plugin;
   gchar *so;
   struct poptOption options[] = {
-    {"gst-inspect-plugin", 'p', POPT_ARG_STRING|POPT_ARGFLAG_STRIP, NULL, 0,
-     "Show plugin details", NULL},
-    {"gst-inspect-scheduler", 's', POPT_ARG_STRING|POPT_ARGFLAG_STRIP, NULL, 0,
-     "Show scheduler details", NULL},
-     POPT_TABLEEND
+    {"gst-inspect-plugin", 'p', POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL, 0,
+        "Show plugin details", NULL},
+    {"gst-inspect-scheduler", 's', POPT_ARG_STRING | POPT_ARGFLAG_STRIP, NULL,
+          0,
+        "Show scheduler details", NULL},
+    POPT_TABLEEND
   };
 
   setlocale (LC_ALL, "");
@@ -862,62 +880,62 @@ main (int argc, char *argv[])
 
   /* if no arguments, print out list of elements */
   if (argc == 1) {
-    print_element_list();
+    print_element_list ();
 
-  /* else we try to get a factory */
+    /* else we try to get a factory */
   } else {
     /* first check for help */
     if (strstr (argv[1], "-help")) {
       g_print ("Usage: %s\t\t\tList all registered elements\n", argv[0]);
       g_print ("       %s element-name\tShow element details\n", argv[0]);
       g_print ("       %s plugin-name[.so]\tShow information about plugin\n",
-               argv[0]);
+          argv[0]);
       return 0;
     }
 
     /* only search for a factory if there's not a '.so' */
-    if (! strstr (argv[1], ".so")) {
+    if (!strstr (argv[1], ".so")) {
       factory = gst_element_factory_find (argv[1]);
 
       /* if there's a factory, print out the info */
       if (factory)
         return print_element_info (factory);
       else {
-         GstPluginFeature* feature;
+        GstPluginFeature *feature;
 
-         /* FIXME implement other pretty print function for these */
-         feature = gst_registry_pool_find_feature (argv[1],
-                                                   GST_TYPE_SCHEDULER_FACTORY);
-         if (feature) {
-           g_print ("%s: a scheduler\n", argv[1]);
-           return 0;
-         }
+        /* FIXME implement other pretty print function for these */
+        feature = gst_registry_pool_find_feature (argv[1],
+            GST_TYPE_SCHEDULER_FACTORY);
+        if (feature) {
+          g_print ("%s: a scheduler\n", argv[1]);
+          return 0;
+        }
 #ifndef GST_DISABLE_INDEX
-         feature = gst_registry_pool_find_feature (argv[1],
-                                                   GST_TYPE_INDEX_FACTORY);
-         if (feature) {
-           g_print ("%s: an index\n", argv[1]);
-           return 0;
-         }
+        feature = gst_registry_pool_find_feature (argv[1],
+            GST_TYPE_INDEX_FACTORY);
+        if (feature) {
+          g_print ("%s: an index\n", argv[1]);
+          return 0;
+        }
 #endif
-         feature = gst_registry_pool_find_feature (argv[1],
-                                                   GST_TYPE_TYPE_FIND_FACTORY);
-         if (feature) {
-           g_print ("%s: a type find function\n", argv[1]);
-           return 0;
-         }
+        feature = gst_registry_pool_find_feature (argv[1],
+            GST_TYPE_TYPE_FIND_FACTORY);
+        if (feature) {
+          g_print ("%s: a type find function\n", argv[1]);
+          return 0;
+        }
 #ifndef GST_DISABLE_URI
-         feature = gst_registry_pool_find_feature (argv[1],
-                                                   GST_TYPE_URI_HANDLER);
-         if (feature) {
-           g_print ("%s: an uri handler\n", argv[1]);
-           return 0;
-         }
+        feature = gst_registry_pool_find_feature (argv[1],
+            GST_TYPE_URI_HANDLER);
+        if (feature) {
+          g_print ("%s: an uri handler\n", argv[1]);
+          return 0;
+        }
 #endif
       }
     } else {
       /* strip the .so */
-      so = strstr(argv[1],".so");
+      so = strstr (argv[1], ".so");
       so[0] = '\0';
     }
 
@@ -929,7 +947,7 @@ main (int argc, char *argv[])
     if (plugin) {
       print_plugin_info (plugin);
     } else {
-      g_print("no such element or plugin '%s'\n", argv[1]);
+      g_print ("no such element or plugin '%s'\n", argv[1]);
       return -1;
     }
   }
